@@ -28,9 +28,9 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: io.h,v 1.14.2.2 2005/07/19 15:02:13 aesok Exp $ */
+/* $Id: io.h,v 1.24 2005/10/25 19:44:25 aesok Exp $ */
 
-/** \defgroup avr_io AVR device-specific IO definitions
+/** \defgroup avr_io <avr/io.h>: AVR device-specific IO definitions
     \code #include <avr/io.h> \endcode
 
     This header file includes the apropriate IO definitions for the
@@ -166,26 +166,52 @@
 #  include <avr/io76c711.h>
 #elif defined (__AVR_AT86RF401__)
 #  include <avr/io86r401.h>
+#elif defined (__AVR_AT90PWM2__)
+#  include <avr/io90pwmx.h>
+#elif defined (__AVR_AT90PWM3__)
+#  include <avr/io90pwmx.h>
 #elif defined (__AVR_ATmega128__)
 #  include <avr/iom128.h>
+#elif defined (__AVR_ATmega1280__)
+#  include <avr/iom1280.h>
+#elif defined (__AVR_ATmega1281__)
+#  include <avr/iom1281.h>
+#elif defined (__AVR_AT90CAN32__)
+#  include <avr/iocan32.h>
+#elif defined (__AVR_AT90CAN64__)
+#  include <avr/iocan64.h>
 #elif defined (__AVR_AT90CAN128__)
 #  include <avr/iocan128.h>
 #elif defined (__AVR_ATmega64__)
 #  include <avr/iom64.h>
+#elif defined (__AVR_ATmega640__)
+#  include <avr/iom640.h>
+#elif defined (__AVR_ATmega644__)
+#  include <avr/iom644.h>
 #elif defined (__AVR_ATmega645__)
 #  include <avr/iom645.h>
 #elif defined (__AVR_ATmega6450__)
 #  include <avr/iom6450.h>
+#elif defined (__AVR_ATmega649__)
+#  include <avr/iom649.h>
+#elif defined (__AVR_ATmega6490__)
+#  include <avr/iom6490.h>
 #elif defined (__AVR_ATmega103__)
 #  include <avr/iom103.h>
 #elif defined (__AVR_ATmega32__)
 #  include <avr/iom32.h>
 #elif defined (__AVR_ATmega323__)
 #  include <avr/iom323.h>
+#elif defined (__AVR_ATmega324__)
+#  include <avr/iom324.h>
 #elif defined (__AVR_ATmega325__)
 #  include <avr/iom325.h>
 #elif defined (__AVR_ATmega3250__)
 #  include <avr/iom3250.h>
+#elif defined (__AVR_ATmega329__)
+#  include <avr/iom329.h>
+#elif defined (__AVR_ATmega3290__)
+#  include <avr/iom3290.h>
 #elif defined (__AVR_ATmega16__)
 #  include <avr/iom16.h>
 #elif defined (__AVR_ATmega161__)
@@ -194,6 +220,8 @@
 #  include <avr/iom162.h>
 #elif defined (__AVR_ATmega163__)
 #  include <avr/iom163.h>
+#elif defined (__AVR_ATmega164__)
+#  include <avr/iom164.h>
 #elif defined (__AVR_ATmega165__)
 #  include <avr/iom165.h>
 #elif defined (__AVR_ATmega168__)
@@ -238,6 +266,12 @@
 #  include <avr/iotn2313.h>
 #elif defined (__AVR_ATtiny13__)
 #  include <avr/iotn13.h>
+#elif defined (__AVR_ATtiny25__)
+#  include <avr/iotn25.h>
+#elif defined (__AVR_ATtiny45__)
+#  include <avr/iotn45.h>
+#elif defined (__AVR_ATtiny85__)
+#  include <avr/iotn85.h>
 /* avr1: the following only supported for assembler programs */
 #elif defined (__AVR_ATtiny28__)
 #  include <avr/iotn28.h>
@@ -265,4 +299,6 @@
 #  endif
 #endif
 
+#include <avr/version.h>
+
 #endif /* _AVR_IO_H_ */
