@@ -29,7 +29,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: wdt.h,v 1.9.2.5 2005/11/06 21:30:13 joerg_wunsch Exp $ */
+/* $Id: wdt.h,v 1.22 2005/11/06 21:27:18 joerg_wunsch Exp $ */
 
 /*
    avr/wdt.h - macros for AVR watchdog timer
@@ -41,7 +41,7 @@
 #include <avr/io.h>
 #include <stdint.h>
 
-/** \defgroup avr_watchdog Watchdog timer handling
+/** \defgroup avr_watchdog <avr/wdt.h>: Watchdog timer handling
     \code #include <avr/wdt.h> \endcode
 
     This header file declares the interface to some inline macros
@@ -96,13 +96,21 @@
 
 #define wdt_reset() __asm__ __volatile__ ("wdr")
 
+#if defined(WDP3)
+# define _WD_PS3_MASK       _BV(WDP3)
+#else
+# define _WD_PS3_MASK       0x00
+#endif /* WDP3 */
+
 #if defined(__AVR_ATtiny2313__) || defined(__AVR_ATmega48__) \
-|| defined(__AVR_ATmega88__) || defined(__AVR_ATmega168__)
+|| defined(__AVR_ATmega88__) || defined(__AVR_ATmega168__) \
+|| defined(__AVR_AT90PWM2__) || defined(__AVR_AT90PWM3__) \
+|| defined(__AVR_ATmega164__) || defined(__AVR_ATmega324__) \
+|| defined(__AVR_ATmega640__) || defined(__AVR_ATmega644__) \
+|| defined(__AVR_ATmega1280__) || defined(__AVR_ATmega1281__)
 #define _WD_CONTROL_REG     WDTCSR
-#define _WD_PS3_MASK        _BV(WDP3)
 #else
 #define _WD_CONTROL_REG     WDTCR
-#define _WD_PS3_MASK        0x00
 #endif
 
 #if defined(WDTOE)
@@ -113,10 +121,18 @@
 
 
 #if defined (__AVR_ATmega169__) || defined(__AVR_AT90CAN128__) \
+|| defined(__AVR_AT90CAN32__) || defined(__AVR_AT90CAN64__) \
 || defined(__AVR_ATmega48__) || defined(__AVR_ATmega88__) \
+|| defined(__AVR_ATmega164__) \
 || defined(__AVR_ATmega165__) || defined(__AVR_ATmega168__) \
+|| defined(__AVR_ATmeg324__) \
 || defined(__AVR_ATmega325__) || defined(__AVR_ATmega3250__) \
-|| defined(__AVR_ATmega645__) || defined(__AVR_ATmega6450__)
+|| defined(__AVR_ATmega329__) || defined(__AVR_ATmega3290__) \
+|| defined(__AVR_ATmega640__) || defined(__AVR_ATmega644__) \
+|| defined(__AVR_ATmega645__) || defined(__AVR_ATmega6450__) \
+|| defined(__AVR_ATmega649__) || defined(__AVR_ATmega6490__) \
+|| defined(__AVR_ATmega1280__) || defined(__AVR_ATmega1281__) \
+|| defined(__AVR_AT90PWM2__) || defined(__AVR_AT90PWM3__)
  
 #define _wdt_write(value)   \
     __asm__ __volatile__ (  \
@@ -213,7 +229,8 @@ __asm__ __volatile__ (  \
    a negligible change.
 
    Possible timeout values are: 15 ms, 30 ms, 60 ms, 120 ms, 250 ms,
-   500 ms, 1 s, 2 s.  Symbolic constants are formed by the prefix
+   500 ms, 1 s, 2 s.  (Some devices also allow for 4 s and 8 s.)
+   Symbolic constants are formed by the prefix
    \c WDTO_, followed by the time.
 
    Example that would select a watchdog timer expiry of approximately
@@ -252,20 +269,31 @@ __asm__ __volatile__ (  \
     See \c WDT0_15MS */
 #define WDTO_2S     7
 
-#if defined(__AVR_ATtiny2313__) || defined(__AVR_ATmega48__) || \
-defined(__AVR_ATmega88__) || defined(__AVR_ATmega168__)
+#if defined(__DOXYGEN__) || defined(WDP3)
 
 /** \ingroup avr_watchdog
     See \c WDT0_15MS
-    Note: This is only available on the ATtiny2313, ATmega48, ATmega88,
-    and the ATmega168.
+    Note: This is only available on the ATtiny2313, ATtiny25,
+    ATtiny45, ATtiny85, ATmega48, ATmega88,
+    ATmega164,
+    ATmega168,
+    ATmega324,
+    ATmega644,
+    ATmega640, ATmega1280, ATmega1281,
+    AT90PWM2, and the AT90PWM3.
     */
 #define WDTO_4S     8
 
 /** \ingroup avr_watchdog
-    See \c WDT0_15MS 
-    Note: This is only available on the ATtiny2313, ATmega48, ATmega88,
-    and the ATmega168.
+    See \c WDT0_15MS
+    Note: This is only available on the ATtiny2313, ATtiny25,
+    ATtiny45, ATtiny85, ATmega48, ATmega88,
+    ATmega164,
+    ATmega168,
+    ATmega324,
+    ATmega644,
+    ATmega640, ATmega1280, ATmega1281,
+    AT90PWM2, and the AT90PWM3.
     */
 #define WDTO_8S     9
 
