@@ -29,11 +29,11 @@
   POSSIBILITY OF SUCH DAMAGE.
 */
 
-/* $Id: vfscanf.c,v 1.9.2.2 2005/11/09 22:01:25 joerg_wunsch Exp $ */
+/* $Id: vfscanf.c,v 1.13 2005/11/09 21:54:33 joerg_wunsch Exp $ */
 
 #include <avr/pgmspace.h>
 #include <ctype.h>
-#include <inttypes.h>
+#include <stdint.h>
 #include <limits.h>
 #include <stdarg.h>
 #include <stdio.h>
@@ -89,7 +89,7 @@
  * bit vector for %[ formats, so it must be at least 256/8 = 32 bytes
  * long.
  */
-#define FLTBUF	40
+#define FLTBUF 40
 #endif
 
 int
@@ -110,8 +110,9 @@ vfscanf(FILE *stream, const char *fmt, va_list ap) {
 #endif
 	uint8_t flags;
 #if SCANF_LEVEL >= SCANF_FLT
-	char	*buf, *bp;
+	char	*bp;
 	char	fltchars[] = "0123456789Ee.";
+	char	buf[FLTBUF];
 #endif
 
 	flags = 0;
@@ -119,9 +120,6 @@ vfscanf(FILE *stream, const char *fmt, va_list ap) {
 	i = 0;
 	rv = EOF;
 	olen = stream->len = 0;
-#if SCANF_LEVEL >= SCANF_FLT
-	buf = 0;
-#endif
 
 	if ((stream->flags & __SRD) == 0)
 		return EOF;
@@ -214,13 +212,6 @@ vfscanf(FILE *stream, const char *fmt, va_list ap) {
 #endif /* SCANF_LEVEL > SCANF_MIN */
 
 			c = tolower(c);
-#if SCANF_LEVEL >= SCANF_FLT
-			if ((c == '[' || c == 'e' || c == 'f' || c == 'g') &&
-			    buf == 0) {
-				if ((buf = malloc(FLTBUF)) == 0)
-					return EOF;
-			}
-#endif /* SCANF_LEVEL >= SCANF_FLT */
 
 			switch (c) {
 #if SCANF_LEVEL > SCANF_MIN
@@ -596,10 +587,6 @@ leave:
 			nconvs++;
 		rv = 0;
 	}
-
-#if SCANF_LEVEL >= SCANF_FLT
-	free(buf);
-#endif
 	/*
 	 * If an error occurs before the first successful conversion,
 	 * we ought to return EOF.  Before getting here, all
